@@ -53,10 +53,12 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
 
     Columnas = pd.read_csv(ruta+'\Equivalencias\SABANA_INVENTARIO.csv', sep=';', header=0)
     Calificaciones = pd.read_csv(ruta+'\Equivalencias\CALIFICACIONES.csv', sep=';', header=0)
+    Calificaciones = Calificaciones.astype({"CALIFICACION DEL TITULO O DEL EMISOR":"float", "CALIFICACION_PRECIA":"str", "ENTIDAD CALIFICADORA":"float"})
     coupFreq = pd.read_csv(ruta+'\Equivalencias\coupFreq.csv', sep=';', header=0)
     dateConv = pd.read_csv(ruta+'\Equivalencias\dateConv.csv', sep=';', header=0)
     Nemos = pd.read_excel(ruta+'\Equivalencias\\NEMOS-ISIN.xlsx')
     Portafolio = pd.read_excel(ruta+'\Insumos\\'+Tipoportafolio+Fecha+'.xlsx', converters={'FECHA EMISION':str, 'FECHA VENCIMIENTO':str, 'FECHA COMPRA':str})
+
     Portafolio = Portafolio.replace("[NULL]", np.nan)
     Indices = pd.read_csv(ruta+'\Equivalencias\TIPO_ACTIVO.csv', sep=';', header=0, usecols =["CLASE DE INVERSION","SEC GROUP","SEC TYPE","secDesc2"], encoding='mbcs')
 
@@ -87,17 +89,18 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
     Portafolio=Portafolio.astype({"CALIFICACION DEL TITULO O DEL EMISOR":"str","ENTIDAD CALIFICADORA":"str","CLASE DE INVERSION":"str"})
 
     Calificaciones1=Calificaciones.loc[:,["CALIFICACION DEL TITULO O DEL EMISOR","CALIFICACION EQUIV"]].drop_duplicates()
-    Calificaciones1=Calificaciones1.astype({"CALIFICACION DEL TITULO O DEL EMISOR":"str"})
+    Calificaciones1 = Calificaciones1.astype({"CALIFICACION DEL TITULO O DEL EMISOR":"str"})
     Portafolio=pd.merge(Portafolio, Calificaciones1, how="left", left_on='CALIFICACION DEL TITULO O DEL EMISOR', right_on='CALIFICACION DEL TITULO O DEL EMISOR')
 
+
     Calificaciones2=Calificaciones.loc[:,["CALIFICACION_PRECIA","CALIFICACION EQUIV"]].drop_duplicates()
-    Calificaciones2=Calificaciones2.astype({"CALIFICACION_PRECIA":"str"})
     Portafolio=pd.merge(Portafolio, Calificaciones2, how="left", left_on='calificacion', right_on='CALIFICACION_PRECIA')
 
     Calificaciones4=Calificaciones.loc[:,["CALIFICACION_PRECIA","CALIFICACION NUMERICA"]].drop_duplicates()
     Calificaciones4=Calificaciones4[-Calificaciones4['CALIFICACION NUMERICA'].isnull()]
-    Calificaciones4=Calificaciones4.astype({"CALIFICACION_PRECIA":"str"})
+
     Portafolio=pd.merge(Portafolio, Calificaciones4, how="left", left_on='calificacion', right_on='CALIFICACION_PRECIA')
+
     Calificaciones3=Calificaciones.loc[:,["ENTIDAD CALIFICADORA","ENTIDAD CALIFICADORA EQUIV","TIPO CALIFICACION"]].drop_duplicates()
     Calificaciones3=Calificaciones3.astype({"ENTIDAD CALIFICADORA":"str"})
 
@@ -109,7 +112,6 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
 
     Calificaciones5=Calificaciones.loc[:,["CALIFICACION EQUIV","CALIFICACION NUMERICA"]].drop_duplicates()
     Calificaciones5=Calificaciones5[-Calificaciones5['CALIFICACION NUMERICA'].isnull()]
-    Calificaciones5=Calificaciones5.astype({"CALIFICACION EQUIV":"str"})
     Portafolio=pd.merge(Portafolio, Calificaciones5, how="left", left_on='CALIFICACION EQUIV', right_on='CALIFICACION EQUIV')
 
     Portafolio['TIPO CALIFICACION'] = np.where(((Portafolio['CALIFICACION NUMERICA_x'].notnull()) & (Portafolio['TIPO CALIFICACION']=="Internacional")),"Local", Portafolio['TIPO CALIFICACION'])
@@ -183,6 +185,10 @@ def procesamiento_aseguradoras(date_port, port_name, ruta, ruta_precia, portfoli
         # Agrego nuevos registros.
         Portafolio = Portafolio.append(add_rows).reset_index(drop=True)
 
+    # Reemplazo fechas con '0' desde CITI.
+    cols = ['issueDt', 'maturity', 'purchaseDt']
+    Portafolio[cols] = Portafolio[cols].replace('0', np.nan)
+
     # Formateo columnas de fechas.
     Portafolio['issueDt'] = pd.to_datetime(Portafolio['issueDt'].str.zfill(8), format='%d%m%Y').dt.strftime("%Y-%m-%d")
     Portafolio['maturity'] = pd.to_datetime(Portafolio['maturity'].str.zfill(8), format='%d%m%Y').dt.strftime("%Y-%m-%d")
